#: Base URL of the ENLYZE platform.
ENLYZE_BASE_URL = "https://app.enlyze.com"

#: URL sub-path where the Timeseries API is deployed on the ENLYZE platform.
TIMESERIES_API_SUB_PATH = "api/timeseries/v1/"

#: URL sub-path where the Production Runs API is deployed on the ENLYZE platform.
PRODUCTION_RUNS_API_SUB_PATH = "api/production-runs/v1/"

#: HTTP timeout for requests to the Timeseries API.
#:
#: Reference: https://www.python-httpx.org/advanced/#timeout-configuration
HTTPX_TIMEOUT = 30.0

#: The separator to use when to separate the variable UUID and the resampling method
#: when querying timeseries data.
VARIABLE_UUID_AND_RESAMPLING_METHOD_SEPARATOR = "||"

#: The minimum allowed resampling interval when resampling timeseries data.
MINIMUM_RESAMPLING_INTERVAL = 10



class EnlyzeError(Exception):
    """Base class for all errors raised by the Timeseries SDK.

    In many situations this error will be raised with a concrete message describing the
    issue.

    """


class InvalidTokenError(EnlyzeError):
    """The ENLYZE platform token is not valid

    Possible reasons:

    - Invalid format (e.g. empty string)
    - Token has expired
    - Typo (e.g. check for excess whitespace)
    - Note: you can **not** use your password as a token

    """


class ResamplingValidationError(EnlyzeError):
    """Invalid request for resampling

    Timeseries data could not be requested from the ENLYZE platform. This may happen
    when a resampling method is incompatible with the variable data type or an invalid
    resampling interval is specified.

    """
